#define MOZ_SOURCE_STAMP dc617d65c9f0cdbbe4351cc1e5c288b05f25f8f7
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-release
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-release/rev/dc617d65c9f0cdbbe4351cc1e5c288b05f25f8f7
